# sokudoku
This is a programmed version of what is called Spritz, in which letters flow at the speed of reading.
This reduces visual fatigue as the user no longer needs to follow the text with their eyes when reading.
The program displays either the text of the image you have entered or the text you have typed word by word.
A space is required for each word as you type.

# Packages required to run sokudoku
pip install pytesseract

brew install mecab

brew install mecab-ipadic

pip install unidic-lite  

pip install mecab-python3

# Result of running sokudoku
The result is displayed in the console.
The size of the text will be the same as the user's environment.

https://github.com/Hikaru163/sokudoku/assets/87521143/ecc87af0-c6e3-4ae3-8b95-509f9bca7b42